@@ -64,9 +64,9 @@ int main( int argc, char *argv[] )
 
   aboutData.setOrganizationDomain( "kde.org" ); //Set this for the DBUS ID
   QApplication app(argc, argv);
+  app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
-  // TODO: for >=KF5.15 use KCrash::initialize();
-  KCrash::setCrashHandler(KCrash::defaultCrashHandler);
+  KCrash::initialize();
 
   QCommandLineParser parser;
   KAboutData::setApplicationData(aboutData);
